@@ -330,7 +330,7 @@ class Reactor(object):
             arguments -- Arguments to give the function.
         """
         warnings.warn(
-            "Call Reactor.scheduler.execute_every directly",
+            "Call Reactor.scheduler.execute_at directly",
             DeprecationWarning,
         )
         function = functools.partial(function, *arguments)
@@ -345,7 +345,7 @@ class Reactor(object):
         arguments -- Arguments to give the function.
         """
         warnings.warn(
-            "Call Reactor.scheduler.execute_every directly",
+            "Call Reactor.scheduler.execute_after directly",
             DeprecationWarning,
         )
         function = functools.partial(function, *arguments)
@@ -993,7 +993,7 @@ class ServerConnection(Connection):
         Set a keepalive to occur every ``interval`` on this connection.
         """
         pinger = functools.partial(self.ping, 'keep-alive')
-        self.reactor.scheduler.execute_every(period=interval, function=pinger)
+        self.reactor.scheduler.execute_every(period=interval, func=pinger)
 
 
 class DCCConnectionError(IRCError):
